.. brille documentation master file, created by
   sphinx-quickstart on Fri Apr 17 11:35:51 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

======
brille
======

You can use ``brille`` to:

- access spacegroup and pointgroup symmetry operations
- determine the first Brillouin zone for a given real space crystallographic
  lattice
- find *an* irreducible Brillouin zone polyhedron for a lattice
- construct a polyhedron-filling connected-point network
- perform linear-interpolation of user-provided data for any reciprocal space
  point at a symmetry-equivalent position within the connected point network.

.. toctree::
  :maxdepth: 1
  :caption: User documents

  install_guide
  motivation
  memory_usage
  tutorial

.. toctree::
  :maxdepth: 2
  :caption: API documents

  brille
  plotting
  utils
  doxygen
  undoc_brille

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
